# Original IGN django generated model as of 2024-10-24
from django.contrib.gis.db import models


class Arrondissement(models.Model):
    geometrie = models.MultiPolygonField(srid=2154, blank=True, null=True)
    cleabs = models.CharField(primary_key=True, max_length=24)
    nom_officiel = models.CharField(blank=True, null=True)
    code_insee_de_l_arrondissement = models.CharField(
        max_length=5, blank=True, null=True
    )
    code_insee_du_departement = models.CharField(max_length=5, blank=True, null=True)
    code_insee_de_la_region = models.CharField(max_length=5, blank=True, null=True)
    liens_vers_autorite_administrative = models.CharField(blank=True, null=True)
    date_creation = models.DateTimeField(blank=True, null=True)
    date_modification = models.DateTimeField(blank=True, null=True)
    date_d_apparition = models.DateField(blank=True, null=True)
    date_de_confirmation = models.DateField(blank=True, null=True)

    # 2024-10-28 :
    # Add field "autorite_administrative" to the model
    autorite_administrative = models.ForeignKey(
        "services_et_activites.ZoneDActiviteOuDInteret",
        on_delete=models.SET_NULL,
        blank=True,
        null=True,
        related_name="arrondissements",
        verbose_name="Autorité administrative",
    )

    class Meta:
        db_table = "administratif_arrondissement"

    # 2024-10-25 :
    # Add __str__ method
    def __str__(self):
        return f"{self.nom_officiel} ({self.code_insee_de_l_arrondissement})"


class ArrondissementMunicipal(models.Model):
    geometrie = models.MultiPolygonField(srid=2154, blank=True, null=True)
    cleabs = models.CharField(primary_key=True, max_length=24)
    code_insee = models.CharField(max_length=5, blank=True, null=True)
    code_insee_de_la_commune_de_rattach = models.CharField(
        max_length=5, blank=True, null=True
    )
    nom_officiel = models.CharField(blank=True, null=True)
    date_creation = models.DateTimeField(blank=True, null=True)
    date_modification = models.DateTimeField(blank=True, null=True)
    date_d_apparition = models.DateField(blank=True, null=True)
    date_de_confirmation = models.DateField(blank=True, null=True)
    lien_vers_chef_lieu = models.CharField(max_length=24, blank=True, null=True)
    liens_vers_autorite_administrative = models.CharField(blank=True, null=True)
    code_postal = models.CharField(max_length=5, blank=True, null=True)
    population = models.IntegerField(blank=True, null=True)

    # 2024-10-28 :
    # Add field "autorite_administrative" to the model
    autorite_administrative = models.ForeignKey(
        "services_et_activites.ZoneDActiviteOuDInteret",
        on_delete=models.SET_NULL,
        blank=True,
        null=True,
        related_name="arrondissements_municipaux",
        verbose_name="Autorité administrative",
    )

    class Meta:
        db_table = "administratif_arrondissement_municipal"

    # 2024-10-25 :
    # Add __str__ method
    def __str__(self):
        return f"{self.nom_officiel} ({self.code_insee})"


class CollectiviteTerritoriale(models.Model):
    geometrie = models.MultiPolygonField(srid=2154, blank=True, null=True)
    cleabs = models.CharField(primary_key=True, max_length=24)
    code_insee = models.CharField(max_length=5, blank=True, null=True)
    code_insee_de_la_region = models.CharField(max_length=5, blank=True, null=True)
    nom_officiel = models.CharField(blank=True, null=True)
    date_creation = models.DateTimeField(blank=True, null=True)
    date_modification = models.DateTimeField(blank=True, null=True)
    date_d_apparition = models.DateField(blank=True, null=True)
    date_de_confirmation = models.DateField(blank=True, null=True)
    liens_vers_autorite_administrative = models.CharField(blank=True, null=True)
    code_siren = models.CharField(max_length=9, blank=True, null=True)

    # 2024-10-28 :
    # Add field "autorite_administrative" to the model
    autorite_administrative = models.ForeignKey(
        "services_et_activites.ZoneDActiviteOuDInteret",
        on_delete=models.SET_NULL,
        blank=True,
        null=True,
        related_name="collectivites_territoriales",
        verbose_name="Autorité administrative",
    )

    class Meta:
        db_table = "administratif_collectivite_territoriale"

    # 2024-10-25 :
    # Add __str__ method
    def __str__(self):
        return f"{self.nom_officiel} ({self.code_insee})"


class Commune(models.Model):
    geometrie = models.MultiPolygonField(srid=2154, blank=True, null=True)
    cleabs = models.CharField(primary_key=True, max_length=24)
    code_insee = models.CharField(max_length=5, blank=True, null=True)
    code_insee_de_l_arrondissement = models.CharField(
        max_length=5, blank=True, null=True
    )
    code_insee_de_la_collectivite_terr = models.CharField(
        max_length=5, blank=True, null=True
    )
    code_insee_du_departement = models.CharField(max_length=5, blank=True, null=True)
    code_insee_de_la_region = models.CharField(max_length=5, blank=True, null=True)
    population = models.IntegerField(blank=True, null=True)
    surface_en_ha = models.IntegerField(blank=True, null=True)
    date_creation = models.DateTimeField(blank=True, null=True)
    date_modification = models.DateTimeField(blank=True, null=True)
    date_d_apparition = models.DateField(blank=True, null=True)
    date_de_confirmation = models.DateField(blank=True, null=True)
    code_postal = models.CharField(max_length=5, blank=True, null=True)
    nom_officiel = models.CharField(blank=True, null=True)
    chef_lieu_d_arrondissement = models.BooleanField(blank=True, null=True)
    chef_lieu_de_collectivite_terr = models.BooleanField(blank=True, null=True)
    chef_lieu_de_departement = models.BooleanField(blank=True, null=True)
    chef_lieu_de_region = models.BooleanField(blank=True, null=True)
    capitale_d_etat = models.BooleanField(blank=True, null=True)
    date_du_recensement = models.DateField(blank=True, null=True)
    organisme_recenseur = models.CharField(max_length=16, blank=True, null=True)
    codes_siren_des_epci = models.CharField(max_length=32, blank=True, null=True)
    lien_vers_chef_lieu = models.CharField(max_length=24, blank=True, null=True)
    liens_vers_autorite_administrative = models.CharField(blank=True, null=True)
    code_siren = models.CharField(max_length=9, blank=True, null=True)

    # 2024-10-28 :
    # Add field "autorite_administrative" to the model
    autorite_administrative = models.ForeignKey(
        "services_et_activites.ZoneDActiviteOuDInteret",
        on_delete=models.SET_NULL,
        blank=True,
        null=True,
        related_name="communes",
        verbose_name="Autorité administrative",
    )

    # 2024-10-25 :
    # Add field "region" to the model
    region = models.ForeignKey(
        "administratif.Region",
        on_delete=models.SET_NULL,
        blank=True,
        null=True,
        related_name="communes",
        verbose_name="Région",
    )

    # 2024-10-25 :
    # Add field "departement" to the model
    departement = models.ForeignKey(
        "administratif.Departement",
        on_delete=models.SET_NULL,
        blank=True,
        null=True,
        related_name="communes",
        verbose_name="Département",
    )

    # 2024-10-25 :
    # Add field "epcis" to the model
    epcis = models.ManyToManyField(
        "administratif.EPCI",
        blank=True,
        related_name="communes",
        verbose_name="EPCIs",
    )

    class Meta:
        db_table = "administratif_commune"

    # 2024-10-25 :
    # Add __str__ method
    def __str__(self):
        return f"{self.nom_officiel} ({self.code_insee})"


class CommuneAssocieeOuDeleguee(models.Model):
    geometrie = models.MultiPolygonField(srid=2154, blank=True, null=True)
    cleabs = models.CharField(primary_key=True, max_length=24)
    code_insee = models.CharField(max_length=5, blank=True, null=True)
    code_insee_de_la_commune_de_rattach = models.CharField(
        max_length=5, blank=True, null=True
    )
    nature = models.CharField(blank=True, null=True)
    nom_officiel = models.CharField(blank=True, null=True)
    date_creation = models.DateTimeField(blank=True, null=True)
    date_modification = models.DateTimeField(blank=True, null=True)
    date_d_apparition = models.DateField(blank=True, null=True)
    date_de_confirmation = models.DateField(blank=True, null=True)
    code_postal = models.CharField(max_length=5, blank=True, null=True)
    lien_vers_chef_lieu = models.CharField(max_length=24, blank=True, null=True)
    liens_vers_autorite_administrative = models.CharField(blank=True, null=True)
    population = models.IntegerField(blank=True, null=True)
    code_siren = models.CharField(max_length=9, blank=True, null=True)

    # 2024-10-28 :
    # Add field "autorite_administrative" to the model
    autorite_administrative = models.ForeignKey(
        "services_et_activites.ZoneDActiviteOuDInteret",
        on_delete=models.SET_NULL,
        blank=True,
        null=True,
        related_name="communes_associees_ou_deleguees",
        verbose_name="Autorité administrative",
    )

    class Meta:
        db_table = "administratif_commune_associee_ou_deleguee"

    # 2024-10-25 :
    # Add __str__ method
    def __str__(self):
        return f"{self.nom_officiel} ({self.code_insee})"


class Condominium(models.Model):
    geometrie = models.MultiPolygonField(srid=2154, blank=True, null=True)
    cleabs = models.CharField(primary_key=True, max_length=24)
    unites_administratives_souveraines = models.CharField(blank=True, null=True)
    date_creation = models.DateTimeField(blank=True, null=True)
    date_modification = models.DateTimeField(blank=True, null=True)
    date_d_apparition = models.DateField(blank=True, null=True)
    date_de_confirmation = models.DateField(blank=True, null=True)
    lien_vers_lieu_dit = models.CharField(max_length=24, blank=True, null=True)

    # 2024-10-28 :
    # Add field "autorite_administrative" to the model
    lieu_dit = models.ForeignKey(
        "lieux_nommes.ZoneDHabitation",
        on_delete=models.SET_NULL,
        blank=True,
        null=True,
        related_name="condominiums",
        verbose_name="Lieu dit",
    )

    class Meta:
        db_table = "administratif_condominium"

    # 2024-10-25 :
    # Add __str__ method
    def __str__(self):
        return f"{self.unites_administratives_souveraines}"


class Departement(models.Model):
    geometrie = models.MultiPolygonField(srid=2154, blank=True, null=True)
    cleabs = models.CharField(primary_key=True, max_length=24)
    code_insee = models.CharField(max_length=5, blank=True, null=True)
    code_insee_de_la_region = models.CharField(max_length=5, blank=True, null=True)
    nom_officiel = models.CharField(blank=True, null=True)
    date_creation = models.DateTimeField(blank=True, null=True)
    date_modification = models.DateTimeField(blank=True, null=True)
    date_d_apparition = models.DateField(blank=True, null=True)
    date_de_confirmation = models.DateField(blank=True, null=True)
    liens_vers_autorite_administrative = models.CharField(blank=True, null=True)
    code_siren = models.CharField(max_length=9, blank=True, null=True)

    # 2024-10-28 :
    # Add field "autorite_administrative" to the model
    autorite_administrative = models.ForeignKey(
        "services_et_activites.ZoneDActiviteOuDInteret",
        on_delete=models.SET_NULL,
        blank=True,
        null=True,
        related_name="departements",
        verbose_name="Autorité administrative",
    )

    # 2024-10-25:
    # Add field "region" to the model
    region = models.ForeignKey(
        "administratif.Region",
        on_delete=models.SET_NULL,
        blank=True,
        null=True,
        related_name="departements",
        verbose_name="Région",
    )

    class Meta:
        db_table = "administratif_departement"

    # 2024-10-25 :
    # Add __str__ method
    def __str__(self):
        return f"{self.nom_officiel} ({self.code_insee})"


class EPCI(models.Model):
    geometrie = models.MultiPolygonField(srid=2154, blank=True, null=True)
    cleabs = models.CharField(primary_key=True, max_length=24)
    code_siren = models.CharField(max_length=9, blank=True, null=True)
    nature = models.CharField(blank=True, null=True)
    nom_officiel = models.CharField(blank=True, null=True)
    date_creation = models.DateTimeField(blank=True, null=True)
    date_modification = models.DateTimeField(blank=True, null=True)
    date_d_apparition = models.DateField(blank=True, null=True)
    date_de_confirmation = models.DateField(blank=True, null=True)
    liens_vers_autorite_administrative = models.CharField(blank=True, null=True)

    # 2024-10-28 :
    # Add field "autorite_administrative" to the model
    autorite_administrative = models.ForeignKey(
        "services_et_activites.ZoneDActiviteOuDInteret",
        on_delete=models.SET_NULL,
        blank=True,
        null=True,
        related_name="epcis",
        verbose_name="Autorité administrative",
    )

    class Meta:
        db_table = "administratif_epci"

    # 2024-10-25 :
    # Add __str__ method
    def __str__(self):
        return f"{self.nom_officiel} ({self.code_siren})"


class Region(models.Model):
    geometrie = models.MultiPolygonField(srid=2154, blank=True, null=True)
    cleabs = models.CharField(primary_key=True, max_length=24)
    code_insee = models.CharField(max_length=5, blank=True, null=True)
    nom_officiel = models.CharField(blank=True, null=True)
    date_creation = models.DateTimeField(blank=True, null=True)
    date_modification = models.DateTimeField(blank=True, null=True)
    date_d_apparition = models.DateField(blank=True, null=True)
    date_de_confirmation = models.DateField(blank=True, null=True)
    liens_vers_autorite_administrative = models.CharField(blank=True, null=True)
    code_siren = models.CharField(max_length=9, blank=True, null=True)

    # 2024-10-28 :
    # Add field "autorite_administrative" to the model
    autorite_administrative = models.ForeignKey(
        "services_et_activites.ZoneDActiviteOuDInteret",
        on_delete=models.SET_NULL,
        blank=True,
        null=True,
        related_name="region",
        verbose_name="Autorité administrative",
    )

    class Meta:
        db_table = "administratif_region"

    # 2024-10-25 :
    # Add __str__ method
    def __str__(self):
        return f"{self.nom_officiel} ({self.code_insee})"



# Django
from django.contrib.gis import admin, admin as gis_admin

# Local application / specific library imports
from .models import (
    EPCI,
    Arrondissement,
    ArrondissementMunicipal,
    CollectiviteTerritoriale,
    Commune,
    CommuneAssocieeOuDeleguee,
    Condominium,
    Departement,
    Region,
)


# Batiment, Cimetiere, ConstructionLineaire, ConstructionPonctuelle, ConstructionSurfacique, LigneOrographique, Pylone, Reservoir, TerrainDeSport, ToponymieBati, BassinVersantTopographique, CoursDEau, DetailHydrographique, LimiteTerreMer, NoeudHydrographique, PlanDEau, SurfaceHydrographique, ToponymieHydrographie, TronconHydrographique, DetailOrographique, LieuDitNonHabite, ToponymieLieuxNommes, ZoneDHabitation, Haie, ZoneDEstran, ZoneDeVegetation, Canalisation, Erp, LigneElectrique, PosteDeTransformation, ToponymieServicesEtActivites, ZoneDActiviteOuDInteret, Aerodrome, EquipementDeTransport, ItineraireAutre, NonCommunication, PisteDAerodrome, PointDAcces, PointDeRepere, PointDuReseau, RouteNumeroteeOuNommee, SectionDePointsDeRepere, ToponymieTransport, TransportParCable, TronconDeRoute, TronconDeVoieFerree, VoieFerreeNommee, VoieNommee, VoieNommeeBeta, ForetPublique, ParcOuReserve, ToponymieZonesReglementees


class GeoAdminReadOnlyMixin:
    # Allow change otherwise OSM maps are not working properly, but not add and delete
    def has_add_permission(self, request, obj=None):
        return False

    def has_delete_permission(self, request, obj=None):
        return False


@admin.register(Arrondissement)
class ArrondissementAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
    list_display = (
        "cleabs",
        "nom_officiel",
        "code_insee_de_l_arrondissement",
        "date_creation",
        "date_modification",
    )
    search_fields = (
        "nom_officiel",
        "code_insee_de_l_arrondissement",
    )
    readonly_fields = [
        "cleabs",
        "nom_officiel",
        "code_insee_de_l_arrondissement",
        "code_insee_du_departement",
        "code_insee_de_la_region",
        "liens_vers_autorite_administrative",
        "date_creation",
        "date_modification",
        "date_d_apparition",
        "date_de_confirmation",
        "autorite_administrative",
    ]
    modifiable = False
    raw_id_fields = ("autorite_administrative",)


@admin.register(ArrondissementMunicipal)
class ArrondissementMunicipalAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
    list_display = (
        "cleabs",
        "nom_officiel",
        "code_insee",
        "code_postal",
        "date_creation",
        "date_modification",
    )
    search_fields = (
        "nom_officiel",
        "code_insee",
        "code_postal",
    )
    readonly_fields = [
        "cleabs",
        "code_insee",
        "code_insee_de_la_commune_de_rattach",
        "nom_officiel",
        "date_creation",
        "date_modification",
        "date_d_apparition",
        "date_de_confirmation",
        "lien_vers_chef_lieu",
        "liens_vers_autorite_administrative",
        "code_postal",
        "population",
        "autorite_administrative",
    ]
    modifiable = False
    raw_id_fields = ("autorite_administrative",)


@admin.register(CollectiviteTerritoriale)
class CollectiviteTerritorialeAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
    list_display = (
        "cleabs",
        "nom_officiel",
        "code_insee",
        "date_creation",
        "date_modification",
    )
    readonly_fields = [
        "cleabs",
        "code_insee",
        "code_insee_de_la_region",
        "nom_officiel",
        "date_creation",
        "date_modification",
        "date_d_apparition",
        "date_de_confirmation",
        "liens_vers_autorite_administrative",
        "code_siren",
        "autorite_administrative",
    ]
    modifiable = False
    raw_id_fields = ("autorite_administrative",)


@admin.register(Commune)
class CommuneAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
    list_display = (
        "cleabs",
        "nom_officiel",
        "code_insee",
        "code_postal",
        "population",
        "surface_en_ha",
        "date_creation",
        "date_modification",
    )
    search_fields = ("nom_officiel", "code_insee", "code_postal")
    readonly_fields = [
        "cleabs",
        "code_insee",
        "code_insee_de_l_arrondissement",
        "code_insee_de_la_collectivite_terr",
        "region",
        "departement",
        "epcis",
        "code_insee_du_departement",
        "code_insee_de_la_region",
        "population",
        "surface_en_ha",
        "date_creation",
        "date_modification",
        "date_d_apparition",
        "date_de_confirmation",
        "code_postal",
        "nom_officiel",
        "chef_lieu_d_arrondissement",
        "chef_lieu_de_collectivite_terr",
        "chef_lieu_de_departement",
        "chef_lieu_de_region",
        "capitale_d_etat",
        "date_du_recensement",
        "organisme_recenseur",
        "codes_siren_des_epci",
        "lien_vers_chef_lieu",
        "liens_vers_autorite_administrative",
        "code_siren",
        "autorite_administrative",
    ]
    modifiable = False
    raw_id_fields = ("autorite_administrative",)


@admin.register(CommuneAssocieeOuDeleguee)
class CommuneAssocieeOuDelegueeAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
    list_display = (
        "cleabs",
        "nom_officiel",
        "code_insee",
        "code_postal",
        "nature",
        "population",
        "date_creation",
        "date_modification",
    )
    search_fields = ("nom_officiel", "code_insee", "code_postal")
    readonly_fields = [
        "cleabs",
        "code_insee",
        "code_insee_de_la_commune_de_rattach",
        "nature",
        "nom_officiel",
        "date_creation",
        "date_modification",
        "date_d_apparition",
        "date_de_confirmation",
        "code_postal",
        "lien_vers_chef_lieu",
        "liens_vers_autorite_administrative",
        "population",
        "code_siren",
        "autorite_administrative",
    ]
    modifiable = False
    raw_id_fields = ("autorite_administrative",)


@admin.register(Condominium)
class CondominiumAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
    list_display = ("cleabs",)
    readonly_fields = [
        "cleabs",
        "unites_administratives_souveraines",
        "date_creation",
        "date_modification",
        "date_d_apparition",
        "date_de_confirmation",
        "lien_vers_lieu_dit",
        "lieu_dit",
    ]


@admin.register(Departement)
class DepartementAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
    list_display = (
        "cleabs",
        "nom_officiel",
        "code_insee",
        "date_creation",
        "date_modification",
    )
    search_fields = (
        "nom_officiel",
        "code_insee",
    )
    readonly_fields = [
        "cleabs",
        "code_insee",
        "code_insee_de_la_region",
        "nom_officiel",
        "date_creation",
        "date_modification",
        "date_d_apparition",
        "date_de_confirmation",
        "liens_vers_autorite_administrative",
        "code_siren",
        "autorite_administrative",
    ]
    modifiable = False
    raw_id_fields = ("autorite_administrative",)


@admin.register(EPCI)
class EPCIAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
    list_display = ("cleabs", "nom_officiel", "date_creation", "date_modification")
    search_fields = ("nom_officiel",)
    readonly_fields = [
        "cleabs",
        "code_siren",
        "nature",
        "nom_officiel",
        "date_creation",
        "date_modification",
        "date_d_apparition",
        "date_de_confirmation",
        "liens_vers_autorite_administrative",
        "autorite_administrative",
    ]
    modifiable = False
    raw_id_fields = ("autorite_administrative",)


@admin.register(Region)
class RegionAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
    list_display = (
        "cleabs",
        "nom_officiel",
        "code_insee",
        "date_creation",
        "date_modification",
    )
    search_fields = (
        "nom_officiel",
        "code_insee",
    )
    readonly_fields = [
        "cleabs",
        "code_insee",
        "nom_officiel",
        "date_creation",
        "date_modification",
        "date_d_apparition",
        "date_de_confirmation",
        "liens_vers_autorite_administrative",
        "code_siren",
        "autorite_administrative",
    ]
    modifiable = False
    raw_id_fields = ("autorite_administrative",)


# TODO: move these admin views to their apps

# @admin.register(Batiment)
# class BatimentAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "usage_1", "usage_2", "nombre_de_logements", "nombre_d_etages", "date_creation", "date_modification")
#     search_fields = ("usage_1", "usage_2",)


# @admin.register(Cimetiere)
# class CimetiereAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "nature", "nature_detaillee", "date_creation", "date_modification")
#     search_fields = ("nature", "nature_detaillee",)


# @admin.register(ConstructionLineaire)
# class ConstructionLineaireAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "nature", "nature_detaillee", "date_creation", "date_modification")
#     search_fields = ("nature", "nature_detaillee",)


# @admin.register(ConstructionPonctuelle)
# class ConstructionPonctuelleAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "nature", "nature_detaillee", "date_creation", "date_modification")
#     search_fields = ("nature", "nature_detaillee",)


# @admin.register(ConstructionSurfacique)
# class ConstructionSurfaciqueAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "nature", "nature_detaillee", "date_creation", "date_modification")
#     search_fields = ("nature", "nature_detaillee",)


# @admin.register(LigneOrographique)
# class LigneOrographiqueAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "nature", "date_creation", "date_modification")
#     search_fields = ("nature",)


# @admin.register(Pylone)
# class PyloneAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")
#     search_fields = ("cleabs",)


# @admin.register(Reservoir)
# class ReservoirAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "nature", "date_creation", "date_modification")
#     search_fields = ("nature",)


# @admin.register(TerrainDeSport)
# class TerrainDeSportAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "nature", "nature_detaillee", "date_creation", "date_modification")
#     search_fields = ("nature", "nature_detaillee")


# @admin.register(ToponymieBati)
# class ToponymieBatiAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs_de_l_objet", "nature_de_l_objet",)
#     search_fields = ("nature_de_l_objet",)


# @admin.register(BassinVersantTopographique)
# class BassinVersantTopographiqueAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("code_bdcarthage", "code_du_bassin_hydrographique", "commentaire_sur_l_objet_hydro", "date_creation", "date_modification")
#     search_fields = ("code_bdcarthage", "code_du_bassin_hydrographique")


# @admin.register(CoursDEau)
# class CoursDEauAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "code_hydrographique", "date_creation", "date_modification")
#     search_fields = ("code_hydrographique",)


# @admin.register(DetailHydrographique)
# class DetailHydrographiqueAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "nature", "nature_detaillee", "date_creation", "date_modification")
#     search_fields = ("nature", "nature_detaillee",)


# @admin.register(LimiteTerreMer)
# class LimiteTerreMerAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(NoeudHydrographique)
# class NoeudHydrographiqueAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(PlanDEau)
# class PlanDEauAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(SurfaceHydrographique)
# class SurfaceHydrographiqueAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(ToponymieHydrographie)
# class ToponymieHydrographieAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs_de_l_objet",)


# @admin.register(TronconHydrographique)
# class TronconHydrographiqueAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(DetailOrographique)
# class DetailOrographiqueAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(LieuDitNonHabite)
# class LieuDitNonHabiteAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(ToponymieLieuxNommes)
# class ToponymieLieuxNommesAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs_de_l_objet",)


# @admin.register(ZoneDHabitation)
# class ZoneDHabitationAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(Haie)
# class HaieAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(ZoneDEstran)
# class ZoneDEstranAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(ZoneDeVegetation)
# class ZoneDeVegetationAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(Canalisation)
# class CanalisationAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(Erp)
# class ErpAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(LigneElectrique)
# class LigneElectriqueAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(PosteDeTransformation)
# class PosteDeTransformationAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(ToponymieServicesEtActivites)
# class ToponymieServicesEtActivitesAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs_de_l_objet",)


# @admin.register(ZoneDActiviteOuDInteret)
# class ZoneDActiviteOuDInteretAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(Aerodrome)
# class AerodromeAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(EquipementDeTransport)
# class EquipementDeTransportAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(ItineraireAutre)
# class ItineraireAutreAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(NonCommunication)
# class NonCommunicationAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(PisteDAerodrome)
# class PisteDAerodromeAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(PointDAcces)
# class PointDAccesAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(PointDeRepere)
# class PointDeRepereAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(PointDuReseau)
# class PointDuReseauAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(RouteNumeroteeOuNommee)
# class RouteNumeroteeOuNommeeAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(SectionDePointsDeRepere)
# class SectionDePointsDeRepereAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(ToponymieTransport)
# class ToponymieTransportAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs_de_l_objet",)


# @admin.register(TransportParCable)
# class TransportParCableAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(TronconDeRoute)
# class TronconDeRouteAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(TronconDeVoieFerree)
# class TronconDeVoieFerreeAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(VoieFerreeNommee)
# class VoieFerreeNommeeAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(VoieNommee)
# class VoieNommeeAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(VoieNommeeBeta)
# class VoieNommeeBetaAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(ForetPublique)
# class ForetPubliqueAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(ParcOuReserve)
# class ParcOuReserveAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs", "date_creation", "date_modification")


# @admin.register(ToponymieZonesReglementees)
# class ToponymieZonesReglementeesAdmin(GeoAdminReadOnlyMixin, gis_admin.OSMGeoAdmin):
#     list_display = ("cleabs_de_l_objet",)



# Standard Library
import logging
import time


class LogTimeMessageMixin:
    logger = logging.getLogger("execution_time")

    def __init__(self, start_time=None, logging_level="info"):
        self.start_time = start_time or time.time()
        self.logging_level = logging_level
        super().__init__()

    def log_message(self, message, logging_level=None):
        logging_level = logging_level or self.logging_level
        current_time = time.time() - self.start_time
        current_time_seconds = int(current_time)
        getattr(self.logger, logging_level)(
            f"[{current_time_seconds} seconds] {message}"
        )



# Standard Library
# from collections import defaultdict

# Django
from django.apps import apps
from django.contrib import admin
from django.contrib.auth.mixins import LoginRequiredMixin
from django.utils.translation import gettext as _
from django.views.generic import TemplateView


# from libs.bdnb_open_data.models import *

# from .constants_91 import DPE_ADEME_91_IDS


class BDNBAnalyzerAdminView(LoginRequiredMixin, TemplateView):
    template_name = "admin/bdnb_analyzer.html"

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)

        # Extraction DPE 91
        # nb_dpe_91 = (
        #     DpeLogement.objects.all()
        #     .filter(relbatimentgroupedpelogement__code_departement_insee="91")
        #     .distinct()
        #     .count()
        # )

        # Extraction communes
        # rel_bat_group_91 = (
        #     RelBatimentGroupeDpeLogement.objects.using("bdnb")
        #     .filter(code_departement_insee="91")
        #     .select_related("cle_interop_adr")
        # )
        # communes_set = set()

        # for rel_bat_group in rel_bat_group_91:
        #     communes_set.add(rel_bat_group.cle_interop_adr.libelle_commune)

        # for commune in communes_set:
        #     print(commune)

        # Extraction batiments groupes set
        # batiment_groupe_set = set()

        # rel_bat_group_91 = (
        #     RelBatimentGroupeDpeLogement.objects.using("bdnb")
        #     .filter(code_departement_insee="91")
        # )

        # for rel_bat_group in rel_bat_group_91:
        #     batiment_groupe_set.add(rel_bat_group.batiment_groupe_id)

        # Extraction communes nb dpe
        # rel_bat_group_91 = (
        #     RelBatimentGroupeDpeLogement.objects.using("bdnb")
        #     .filter(code_departement_insee="91")
        #     .distinct()
        #     .select_related("cle_interop_adr")
        # )
        # communes_count = defaultdict(int)

        # for rel_bat_group in rel_bat_group_91:
        #     communes_count[rel_bat_group.cle_interop_adr.libelle_commune] += 1

        # for commune, count in communes_count.items():
        #     print(f"{commune}: {count}")

        # Nombre de DPE représentatifs logements
        # dpe_representatif_logements = (
        #     BatimentGroupeDpeRepresentatifLogement.objects.using("bdnb").filter(
        #         code_departement_insee="91"
        #     )
        # )

        # nb_batiment_groupe_unique = set()

        # for dpe_representatif_logement in dpe_representatif_logements:
        #     nb_batiment_groupe_unique.add(dpe_representatif_logement.batiment_groupe_id)

        # nb_batiment_groupe_essonne = (
        #     BatimentGroupe.objects.using("bdnb")
        #     .filter(code_commune_insee__startswith="91")
        #     .distinct()
        #     .count()
        # )

        # nb_dpe_par_batiment_groupe = defaultdict(int)
        # rel_bat_group_91 = (
        #     RelBatimentGroupeDpeLogement.objects.using("bdnb")
        #     .filter(code_departement_insee="91")
        #     .distinct()
        # )

        # for rel_bat_group in rel_bat_group_91:
        #     nb_dpe_par_batiment_groupe[rel_bat_group.batiment_groupe_id] += 1

        # per_count_number = defaultdict(int)

        # for batiment_groupe, count in nb_dpe_par_batiment_groupe.items():
        #     if count > 1:
        #         per_count_number[count] += 1

        #     if count == 1990:
        #         bat_groupe_obj = BatimentGroupe.objects.using("bdnb").get(
        #             pk=batiment_groupe
        #         )

        #     rel_batiment_groupe_dpe_logements = (
        #         RelBatimentGroupeDpeLogement.objects.using("bdnb")
        #         .filter(batiment_groupe_id=batiment_groupe)
        #         .select_related("identifiant_dpe")
        #     )

        #     dpe_representatif = (
        #         bat_groupe_obj.batimentgroupedperepresentatiflogement
        #     )

        #     # Standard Library
        #     import pprint
        #     pprint.pprint(dpe_representatif.__dict__)

        # if count > 500:
        #     bat_groupe_obj = BatimentGroupe.objects.using("bdnb").get(
        #         pk=batiment_groupe
        #     )
        #     print(
        #         str(count)
        #         + " "
        #         + bat_groupe_obj.batimentgroupeadresse.libelle_adr_principale_ban
        #     )

        # per_count_number = dict(sorted(per_count_number.items()))

        # for count, number in per_count_number.items():
        #     print(f"{count}: {number}")

        # ademe_dpe_91_set = set(DPE_ADEME_91_IDS)
        # ademe_dpe_91_set_list = list(DPE_ADEME_91_IDS)

        # bdnb_dpe_91_set = set(
        #     DpeLogement.objects.using("bdnb")
        #     .filter(relbatimentgroupedpelogement__code_departement_insee="91")
        #     .values_list("identifiant_dpe", flat=True)
        # )

        # bdnb_dpe_91_set_list = list(bdnb_dpe_91_set)

        # common_dpe_91_set = ademe_dpe_91_set.intersection(bdnb_dpe_91_set)

        # only_in_ademe = ademe_dpe_91_set.difference(bdnb_dpe_91_set)
        # only_in_bdnb = bdnb_dpe_91_set.difference(ademe_dpe_91_set)

        # only_in_ademe_list = list(only_in_ademe)
        # only_in_bdnb_list = list(only_in_bdnb)

        # bdnb_dpe_91_set = (
        #     DpeLogement.objects.using("bdnb")
        #     .filter(
        #         relbatimentgroupedpelogement__code_departement_insee="91",
        #         classe_bilan_dpe__in=[
        #             "A",
        #             "B",
        #             "C",
        #             "D",
        #             "E",
        #             "F",
        #             "G",
        #             "a",
        #             "b",
        #             "c",
        #             "d",
        #             "e",
        #             "f",
        #             "g",
        #         ],
        #     )
        #     .distinct()
        # )

        # DPE dupliqués dans la BDNB
        # identifiants_dpe = (
        #     DpeLogement.objects.using("bdnb")
        #     .filter(relbatimentgroupedpelogement__code_departement_insee="91")
        #     .distinct()
        #     .values_list("identifiant_dpe", flat=True)
        # )

        # dpe_count = defaultdict(int)
        # for identifiant_dpe in identifiants_dpe:
        #     dpe_count[identifiant_dpe] += 1

        # dpe_count = dict(sorted(dpe_count.items(), key=lambda item: item[1]))

        # breakpoint()

        app_label = "bdnb_open_data"
        app_config = apps.get_app_config(app_label)
        context["app_label"] = app_label
        context["app_config"] = app_config
        context["title"] = _("Analyse des données de la BDNB")

        context.update(admin.site.each_context(self.request))
        return context



# Generated by Django 4.2.11 on 2024-10-28 10:55

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("administratif", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="commune",
            name="departement",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="communes",
                to="administratif.departement",
                verbose_name="Département",
            ),
        ),
        migrations.AddField(
            model_name="commune",
            name="epcis",
            field=models.ManyToManyField(
                blank=True,
                related_name="communes",
                to="administratif.epci",
                verbose_name="EPCIs",
            ),
        ),
        migrations.AddField(
            model_name="commune",
            name="region",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="communes",
                to="administratif.region",
                verbose_name="Région",
            ),
        ),
        migrations.AddField(
            model_name="departement",
            name="region",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="departements",
                to="administratif.region",
                verbose_name="Région",
            ),
        ),
        migrations.AddField(
            model_name="arrondissement",
            name="autorite_administrative",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="arrondissements",
                to="services_et_activites.zonedactiviteoudinteret",
                verbose_name="Autorité administrative",
            ),
        ),
        migrations.AddField(
            model_name="arrondissementmunicipal",
            name="autorite_administrative",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="arrondissements_municipaux",
                to="services_et_activites.zonedactiviteoudinteret",
                verbose_name="Autorité administrative",
            ),
        ),
        migrations.AddField(
            model_name="collectiviteterritoriale",
            name="autorite_administrative",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="collectivites_territoriales",
                to="services_et_activites.zonedactiviteoudinteret",
                verbose_name="Autorité administrative",
            ),
        ),
        migrations.AddField(
            model_name="commune",
            name="autorite_administrative",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="communes",
                to="services_et_activites.zonedactiviteoudinteret",
                verbose_name="Autorité administrative",
            ),
        ),
        migrations.AddField(
            model_name="communeassocieeoudeleguee",
            name="autorite_administrative",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="communes_associees_ou_deleguees",
                to="services_et_activites.zonedactiviteoudinteret",
                verbose_name="Autorité administrative",
            ),
        ),
        migrations.AddField(
            model_name="condominium",
            name="lieu_dit",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="condominiums",
                to="lieux_nommes.zonedhabitation",
                verbose_name="Lieu dit",
            ),
        ),
        migrations.AddField(
            model_name="departement",
            name="autorite_administrative",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="departements",
                to="services_et_activites.zonedactiviteoudinteret",
                verbose_name="Autorité administrative",
            ),
        ),
        migrations.AddField(
            model_name="epci",
            name="autorite_administrative",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="epcis",
                to="services_et_activites.zonedactiviteoudinteret",
                verbose_name="Autorité administrative",
            ),
        ),
        migrations.AddField(
            model_name="region",
            name="autorite_administrative",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="region",
                to="services_et_activites.zonedactiviteoudinteret",
                verbose_name="Autorité administrative",
            ),
        ),
    ]



# Generated by Django 4.2.11 on 2024-10-24 15:57

import django.contrib.gis.db.models.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Arrondissement",
            fields=[
                (
                    "geometrie",
                    django.contrib.gis.db.models.fields.MultiPolygonField(
                        blank=True, null=True, srid=2154
                    ),
                ),
                (
                    "cleabs",
                    models.CharField(max_length=24, primary_key=True, serialize=False),
                ),
                ("nom_officiel", models.CharField(blank=True, null=True)),
                (
                    "code_insee_de_l_arrondissement",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                (
                    "code_insee_du_departement",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                (
                    "code_insee_de_la_region",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                (
                    "liens_vers_autorite_administrative",
                    models.CharField(blank=True, null=True),
                ),
                ("date_creation", models.DateTimeField(blank=True, null=True)),
                ("date_modification", models.DateTimeField(blank=True, null=True)),
                ("date_d_apparition", models.DateField(blank=True, null=True)),
                ("date_de_confirmation", models.DateField(blank=True, null=True)),
            ],
            options={
                "db_table": "administratif_arrondissement",
            },
        ),
        migrations.CreateModel(
            name="ArrondissementMunicipal",
            fields=[
                (
                    "geometrie",
                    django.contrib.gis.db.models.fields.MultiPolygonField(
                        blank=True, null=True, srid=2154
                    ),
                ),
                (
                    "cleabs",
                    models.CharField(max_length=24, primary_key=True, serialize=False),
                ),
                ("code_insee", models.CharField(blank=True, max_length=5, null=True)),
                (
                    "code_insee_de_la_commune_de_rattach",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                ("nom_officiel", models.CharField(blank=True, null=True)),
                ("date_creation", models.DateTimeField(blank=True, null=True)),
                ("date_modification", models.DateTimeField(blank=True, null=True)),
                ("date_d_apparition", models.DateField(blank=True, null=True)),
                ("date_de_confirmation", models.DateField(blank=True, null=True)),
                (
                    "lien_vers_chef_lieu",
                    models.CharField(blank=True, max_length=24, null=True),
                ),
                (
                    "liens_vers_autorite_administrative",
                    models.CharField(blank=True, null=True),
                ),
                ("code_postal", models.CharField(blank=True, max_length=5, null=True)),
                ("population", models.IntegerField(blank=True, null=True)),
            ],
            options={
                "db_table": "administratif_arrondissement_municipal",
            },
        ),
        migrations.CreateModel(
            name="CollectiviteTerritoriale",
            fields=[
                (
                    "geometrie",
                    django.contrib.gis.db.models.fields.MultiPolygonField(
                        blank=True, null=True, srid=2154
                    ),
                ),
                (
                    "cleabs",
                    models.CharField(max_length=24, primary_key=True, serialize=False),
                ),
                ("code_insee", models.CharField(blank=True, max_length=5, null=True)),
                (
                    "code_insee_de_la_region",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                ("nom_officiel", models.CharField(blank=True, null=True)),
                ("date_creation", models.DateTimeField(blank=True, null=True)),
                ("date_modification", models.DateTimeField(blank=True, null=True)),
                ("date_d_apparition", models.DateField(blank=True, null=True)),
                ("date_de_confirmation", models.DateField(blank=True, null=True)),
                (
                    "liens_vers_autorite_administrative",
                    models.CharField(blank=True, null=True),
                ),
                ("code_siren", models.CharField(blank=True, max_length=9, null=True)),
            ],
            options={
                "db_table": "administratif_collectivite_territoriale",
            },
        ),
        migrations.CreateModel(
            name="Commune",
            fields=[
                (
                    "geometrie",
                    django.contrib.gis.db.models.fields.MultiPolygonField(
                        blank=True, null=True, srid=2154
                    ),
                ),
                (
                    "cleabs",
                    models.CharField(max_length=24, primary_key=True, serialize=False),
                ),
                ("code_insee", models.CharField(blank=True, max_length=5, null=True)),
                (
                    "code_insee_de_l_arrondissement",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                (
                    "code_insee_de_la_collectivite_terr",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                (
                    "code_insee_du_departement",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                (
                    "code_insee_de_la_region",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                ("population", models.IntegerField(blank=True, null=True)),
                ("surface_en_ha", models.IntegerField(blank=True, null=True)),
                ("date_creation", models.DateTimeField(blank=True, null=True)),
                ("date_modification", models.DateTimeField(blank=True, null=True)),
                ("date_d_apparition", models.DateField(blank=True, null=True)),
                ("date_de_confirmation", models.DateField(blank=True, null=True)),
                ("code_postal", models.CharField(blank=True, max_length=5, null=True)),
                ("nom_officiel", models.CharField(blank=True, null=True)),
                (
                    "chef_lieu_d_arrondissement",
                    models.BooleanField(blank=True, null=True),
                ),
                (
                    "chef_lieu_de_collectivite_terr",
                    models.BooleanField(blank=True, null=True),
                ),
                (
                    "chef_lieu_de_departement",
                    models.BooleanField(blank=True, null=True),
                ),
                ("chef_lieu_de_region", models.BooleanField(blank=True, null=True)),
                ("capitale_d_etat", models.BooleanField(blank=True, null=True)),
                ("date_du_recensement", models.DateField(blank=True, null=True)),
                (
                    "organisme_recenseur",
                    models.CharField(blank=True, max_length=16, null=True),
                ),
                (
                    "codes_siren_des_epci",
                    models.CharField(blank=True, max_length=32, null=True),
                ),
                (
                    "lien_vers_chef_lieu",
                    models.CharField(blank=True, max_length=24, null=True),
                ),
                (
                    "liens_vers_autorite_administrative",
                    models.CharField(blank=True, null=True),
                ),
                ("code_siren", models.CharField(blank=True, max_length=9, null=True)),
            ],
            options={
                "db_table": "administratif_commune",
            },
        ),
        migrations.CreateModel(
            name="CommuneAssocieeOuDeleguee",
            fields=[
                (
                    "geometrie",
                    django.contrib.gis.db.models.fields.MultiPolygonField(
                        blank=True, null=True, srid=2154
                    ),
                ),
                (
                    "cleabs",
                    models.CharField(max_length=24, primary_key=True, serialize=False),
                ),
                ("code_insee", models.CharField(blank=True, max_length=5, null=True)),
                (
                    "code_insee_de_la_commune_de_rattach",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                ("nature", models.CharField(blank=True, null=True)),
                ("nom_officiel", models.CharField(blank=True, null=True)),
                ("date_creation", models.DateTimeField(blank=True, null=True)),
                ("date_modification", models.DateTimeField(blank=True, null=True)),
                ("date_d_apparition", models.DateField(blank=True, null=True)),
                ("date_de_confirmation", models.DateField(blank=True, null=True)),
                ("code_postal", models.CharField(blank=True, max_length=5, null=True)),
                (
                    "lien_vers_chef_lieu",
                    models.CharField(blank=True, max_length=24, null=True),
                ),
                (
                    "liens_vers_autorite_administrative",
                    models.CharField(blank=True, null=True),
                ),
                ("population", models.IntegerField(blank=True, null=True)),
                ("code_siren", models.CharField(blank=True, max_length=9, null=True)),
            ],
            options={
                "db_table": "administratif_commune_associee_ou_deleguee",
            },
        ),
        migrations.CreateModel(
            name="Condominium",
            fields=[
                (
                    "geometrie",
                    django.contrib.gis.db.models.fields.MultiPolygonField(
                        blank=True, null=True, srid=2154
                    ),
                ),
                (
                    "cleabs",
                    models.CharField(max_length=24, primary_key=True, serialize=False),
                ),
                (
                    "unites_administratives_souveraines",
                    models.CharField(blank=True, null=True),
                ),
                ("date_creation", models.DateTimeField(blank=True, null=True)),
                ("date_modification", models.DateTimeField(blank=True, null=True)),
                ("date_d_apparition", models.DateField(blank=True, null=True)),
                ("date_de_confirmation", models.DateField(blank=True, null=True)),
                (
                    "lien_vers_lieu_dit",
                    models.CharField(blank=True, max_length=24, null=True),
                ),
            ],
            options={
                "db_table": "administratif_condominium",
            },
        ),
        migrations.CreateModel(
            name="Departement",
            fields=[
                (
                    "geometrie",
                    django.contrib.gis.db.models.fields.MultiPolygonField(
                        blank=True, null=True, srid=2154
                    ),
                ),
                (
                    "cleabs",
                    models.CharField(max_length=24, primary_key=True, serialize=False),
                ),
                ("code_insee", models.CharField(blank=True, max_length=5, null=True)),
                (
                    "code_insee_de_la_region",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                ("nom_officiel", models.CharField(blank=True, null=True)),
                ("date_creation", models.DateTimeField(blank=True, null=True)),
                ("date_modification", models.DateTimeField(blank=True, null=True)),
                ("date_d_apparition", models.DateField(blank=True, null=True)),
                ("date_de_confirmation", models.DateField(blank=True, null=True)),
                (
                    "liens_vers_autorite_administrative",
                    models.CharField(blank=True, null=True),
                ),
                ("code_siren", models.CharField(blank=True, max_length=9, null=True)),
            ],
            options={
                "db_table": "administratif_departement",
            },
        ),
        migrations.CreateModel(
            name="EPCI",
            fields=[
                (
                    "geometrie",
                    django.contrib.gis.db.models.fields.MultiPolygonField(
                        blank=True, null=True, srid=2154
                    ),
                ),
                (
                    "cleabs",
                    models.CharField(max_length=24, primary_key=True, serialize=False),
                ),
                ("code_siren", models.CharField(blank=True, max_length=9, null=True)),
                ("nature", models.CharField(blank=True, null=True)),
                ("nom_officiel", models.CharField(blank=True, null=True)),
                ("date_creation", models.DateTimeField(blank=True, null=True)),
                ("date_modification", models.DateTimeField(blank=True, null=True)),
                ("date_d_apparition", models.DateField(blank=True, null=True)),
                ("date_de_confirmation", models.DateField(blank=True, null=True)),
                (
                    "liens_vers_autorite_administrative",
                    models.CharField(blank=True, null=True),
                ),
            ],
            options={
                "db_table": "administratif_epci",
            },
        ),
        migrations.CreateModel(
            name="Region",
            fields=[
                (
                    "geometrie",
                    django.contrib.gis.db.models.fields.MultiPolygonField(
                        blank=True, null=True, srid=2154
                    ),
                ),
                (
                    "cleabs",
                    models.CharField(max_length=24, primary_key=True, serialize=False),
                ),
                ("code_insee", models.CharField(blank=True, max_length=5, null=True)),
                ("nom_officiel", models.CharField(blank=True, null=True)),
                ("date_creation", models.DateTimeField(blank=True, null=True)),
                ("date_modification", models.DateTimeField(blank=True, null=True)),
                ("date_d_apparition", models.DateField(blank=True, null=True)),
                ("date_de_confirmation", models.DateField(blank=True, null=True)),
                (
                    "liens_vers_autorite_administrative",
                    models.CharField(blank=True, null=True),
                ),
                ("code_siren", models.CharField(blank=True, max_length=9, null=True)),
            ],
            options={
                "db_table": "administratif_region",
            },
        ),
    ]
